@@ -1,5 +1,5 @@
 from .shell import Main, Shell
-from .decoration import alias, ignore
+from .decoration import alias, ignore, desc
 from .types import Input, Options
 from .console import *
 from .util import cmd
