@@ -39,25 +39,15 @@ class Alias(Context):
     def get(self, name):
         return self.context.get(name)
 
+    def find_alias(self, name):
+        for a, n in self.context.items():
+            if n == name:
+                return a
+
 
 alias_set = Alias()
 
 
-class Argument(Context):
-    def __init__(self, func_name):
-        self.func_name = func_name
-        super().__init__()
-
-    def add(self, name, f):
-        self.context[name] = f
-
-    def pop(self, name):
-        return self.context.pop(name)
-
-    def get(self, name):
-        return self.context.get(name)
-
-
 class Ignore(Context):
     def __init__(self):
         super().__init__([])
@@ -84,3 +74,14 @@ class Options(Context):
 
 
 opt_set = Options()
+
+
+class Descriptions(Context):
+    def add(self, name, desc):
+        self.context[name] = desc
+
+    def get(self, name):
+        return self.context.get(name)
+
+
+desc_set = Descriptions()
