@@ -5,11 +5,12 @@ from queue import Queue
 
 from .console import *
 from .comment import parse_comment
-from .context import alias_set, ignore_set, opt_set
+from .context import alias_set, ignore_set, opt_set, desc_set
 from .options import OptionsTagHandler, SimpleOptionsHandler
 from .types import Options
 from .exceptions import CommandError, COMMAND_NOT_FOUND
-from .util import cmd
+from .util import cmd, find_description
+from .definition import check_definition
 
 from typing import Optional
 
@@ -24,21 +25,30 @@ class CommandHandler:
 
         self.tasks = cls()
 
+        self.context_mapping = {}
+        for k, f in self.tasks.__ls_task__.items():
+            if isinstance(self.select_handler(f), OptionsTagHandler):
+                self.context_mapping[k] = check_definition(f)
+
         # if args is empty.
         if self.args:
             self.action = self.args[0]
         else:
             self.help()
 
-    def load_parameters(self, func):
+    def select_handler(self, func):
         if isinstance(self.tasks.__options_handler__, SimpleOptionsHandler):
             for t in func.__annotations__.values():
                 if isinstance(t, Options):
-                    self.tasks.__options_handler__ = OptionsTagHandler()
-                    break
+                    return OptionsTagHandler()
 
             if not opt_set.empty and opt_set.get(func.__name__):
-                self.tasks.__options_handler__ = OptionsTagHandler()
+                return OptionsTagHandler()
+        return SimpleOptionsHandler()
+
+    def load_parameters(self, func):
+        handler = self.select_handler(func)
+        self.tasks.__options_handler__ = handler
 
         if self.tasks.__options_handler__.options_type == 'Queue':
             options = Queue()
@@ -50,8 +60,11 @@ class CommandHandler:
 
     def command_not_found(self, action, throws=True):
         instruction = {}
-        instruction.update(alias_set.context)
         instruction.update(self.tasks.__ls_task__)
+        for v in alias_set.context.values():
+            if v in self.tasks.__ls_task__:
+                del instruction[v]
+        instruction.update(alias_set.context)
 
         similarity_dice = {}
         for i in instruction:
@@ -79,8 +92,8 @@ class CommandHandler:
         the command will be executed by the program specified by `__default_bash__`
         """
         if self.tasks.__default_bash__:
-            cmd = ' '.join(self.args[1:])
-            os.system(f'{self.tasks.__default_bash__} {cmd}')
+            cmdarg = ' '.join(self.args)
+            os.system(f'{self.tasks.__default_bash__} {cmdarg}')
         else:
             self.command_not_found(self.action)
 
@@ -97,27 +110,24 @@ class CommandHandler:
                 option = None
             self.help(option)
 
-        if not alias_set.empty:
-            if alias_set.get(action):
-                action = alias_set.get(action)
-
-                if ignore_set.exist(action):
-                    return
+        if not alias_set.empty and alias_set.get(action):
+            action = alias_set.get(action)
 
         func = getattr(self.tasks, action, None)
 
         if func is None:
-            self.default_command()
+            return self.default_command()
 
         if not callable(func):
             return self.command_not_found(self.action)
 
         self.load_parameters(func)
 
+        context = self.context_mapping.get(action)
         if isinstance(self.tasks.__options_handler__, type):
-            args = self.tasks.__options_handler__().process_options(func, self.options)
+            args = self.tasks.__options_handler__().process_options(func, self.options, context)
         else:
-            args = self.tasks.__options_handler__.process_options(func, self.options)
+            args = self.tasks.__options_handler__.process_options(func, self.options, context)
 
         self.tasks.__before__()
 
@@ -147,17 +157,31 @@ class CommandHandler:
                 self.command_not_found(self.action, False)
         else:
             output('帮助:')
-            output('  <shell> -h')
-            output('  <shell> -h <action>')
+            output('    <shell> -h')
+            output('    <shell> -h <action>')
             output('用法:')
-            output('  <shell> <action> [options...]', end='\n\n')
+            output('    <shell> <action> [options...]', end='\n\n')
 
             cm = sorted(self.tasks.__ls_task__)
             output('命令:')
             for k in cm:
                 # func_name = self.tasks.__ls_task__[k]
-                space = ' '
-                opt = f'  {k}'
+                desc = desc_set.get(k)
+                if not desc:
+                    desc = find_description(getattr(self.tasks, k, None))
+
+                alias = alias_set.find_alias(k)
+                k = alias if alias else k
+
+                if desc:
+                    nspace = 18 - len(k)
+                    if nspace > 0:
+                        space = ' ' * nspace
+                    else:
+                        space = ''
+                    desc = f'{space}{desc}'
+
+                opt = f'    {k}{desc}'
                 output(opt)
         sys.exit()
 
@@ -199,7 +223,7 @@ class Main:
     ignore_set.add('cmd')
 
     def cmd(self, *args, **kwargs):
-        cmd(*args, **kwargs)
+        return cmd(*args, **kwargs)
 
     def __before__(self):
         pass
